@@ -40,7 +40,7 @@ class RigidBodyErrors: public ObjectErrors
 
 public:
     /** Constructs RigidBodyErrors */
-    RigidBodyErrors(Item* owner = 0)
+    explicit RigidBodyErrors(Item* owner = 0)
         : ObjectErrors(owner), _positionVariance(0,0), _angleVariance(0), _velocityVariance(0,0),
           _angularVelocityVariance(0), _forceVariance(0,0), _torqueVariance(0),
           _massVariance(0), _inertiaVariance(0) {}
@@ -92,7 +92,7 @@ public:
                             const Vector2d& forceVariance,
                             const Vector2d& positionVariance);
 
-    /** Apply torque (but no force) variancee to the body */
+    /** Apply torque (but no force) variance to the body */
     void applyTorqueVariance(double torqueVariance) { _torqueVariance += torqueVariance; }
 
     /** Get mass variance */
